=============================
MetaNetX Post-Processing
=============================

.. image:: https://img.shields.io/pypi/v/metanetx-post.svg
   :target: https://pypi.org/project/metanetx-post/
   :alt: Current PyPI Version

.. image:: https://img.shields.io/pypi/pyversions/metanetx-post.svg
   :target: https://pypi.org/project/metanetx-post/
   :alt: Supported Python Versions

.. image:: https://img.shields.io/pypi/l/metanetx-post.svg
   :target: https://www.apache.org/licenses/LICENSE-2.0
   :alt: Apache Software License Version 2.0

.. image:: https://img.shields.io/badge/Contributor%20Covenant-v1.4%20adopted-ff69b4.svg
   :target: https://github.com/Midnighter/metanetx-post/blob/master/.github/CODE_OF_CONDUCT.md
   :alt: Code of Conduct

.. image:: https://img.shields.io/travis/Midnighter/metanetx-post/master.svg?label=Travis%20CI
   :target: https://travis-ci.org/Midnighter/metanetx-post
   :alt: Travis CI

.. image:: https://ci.appveyor.com/api/projects/status/github/Midnighter/metanetx-post?branch=master&svg=true
   :target: https://ci.appveyor.com/project/Midnighter/metanetx-post
   :alt: AppVeyor

.. image:: https://codecov.io/gh/Midnighter/metanetx-post/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/Midnighter/metanetx-post
   :alt: Codecov

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Black

.. image:: https://readthedocs.org/projects/metanetx-post/badge/?version=latest
   :target: https://metanetx-post.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. summary-start

Enrich the information coming from MetaNetX from additional sources.

Usage
=====

Please use the command line program help to explore use-cases.

.. code-block:: console

    mnx-post --help

Install
=======

It's as simple as:

.. code-block:: console

    pip install metanetx-post

Copyright
=========

* Copyright © 2020, Moritz E. Beber.
* Free software distributed under the `Apache Software License 2.0
  <https://www.apache.org/licenses/LICENSE-2.0>`_.

.. summary-end
